﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using C1.WPF.FlexGrid;

namespace WpfFlexGridSubtotals
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();
            List<Sales> salesList = new List<Sales>();
            Random rnd = new Random();
            for (int i = 1; i <= 13; i++)
            {
                Sales s = new Sales();
                s.Direction = (i < 7) ? "Inbound" : "Outbound";
                s.Region = (i < 3) ? "North" : (i < 7) ? "South" : (i < 10) ? "East" : "West";
                s.Q1 = rnd.Next(1000);
                s.Q2 = rnd.Next(1000);
                s.Q3 = rnd.Next(1000);
                s.Q4 = rnd.Next(1000);
                salesList.Add(s);
            }
            ListCollectionView view = new ListCollectionView(salesList);
            view.GroupDescriptions.Add(new PropertyGroupDescription("GrandTotal"));
            view.GroupDescriptions.Add(new PropertyGroupDescription("Direction"));
            view.GroupDescriptions.Add(new PropertyGroupDescription("Region"));
            c1FlexGrid1.ItemsSource = view;

            c1FlexGrid1.Columns["Q1"].GroupAggregate = C1.WPF.FlexGrid.Aggregate.Sum;
            c1FlexGrid1.Columns["Q2"].GroupAggregate = C1.WPF.FlexGrid.Aggregate.Sum;
            c1FlexGrid1.Columns["Q3"].GroupAggregate = C1.WPF.FlexGrid.Aggregate.Sum;
            c1FlexGrid1.Columns["Q4"].GroupAggregate = C1.WPF.FlexGrid.Aggregate.Sum;

            c1FlexGrid1.GroupHeaderConverter = new TotalsGroupHeader();

            //Turn on cell merging
            c1FlexGrid1.AllowMerging = AllowMerging.All;
            //Allow merging in some columns
            c1FlexGrid1.Columns["Direction"].AllowMerging = true;
            c1FlexGrid1.Columns["Region"].AllowMerging = true;
            c1FlexGrid1.AlternatingRowBackground = new SolidColorBrush(Color.FromArgb(255, 255, 255, 255));
            c1FlexGrid1.RowBackground = new SolidColorBrush(Color.FromArgb(255, 255, 255, 255));
        }
    }
    
    // class used to format group captions for display
    public class TotalsGroupHeader : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            var gr = parameter as GroupRow;
            var group = gr.Group;
            if (group != null && gr != null && targetType == typeof(string))
            {
                return group.Name != DependencyProperty.UnsetValue ? string.Format("Total for {0}", group.Name) : "Grand Total";
            } return value;
        }
        public object ConvertBack(object value, Type targetType,
            object parameter,
            System.Globalization.CultureInfo culture)
        {
            return value;
        }
    }

    public class Sales
    {
        public int GrandTotal;
        public string Direction { get; set; }
        public string Region { get; set; }
        public int Q1 { get; set; }
        public int Q2 { get; set; }
        public int Q3 { get; set; }
        public int Q4 { get; set; }
    }
}
